package com.example.fitmarcetplacekuzminiv.Screens

import androidx.compose.foundation.layout.*
import androidx.compose.material3.*
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.input.PasswordVisualTransformation
import androidx.compose.ui.text.input.TextFieldValue
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.navigation.NavController
import com.example.fitmarcetplacekuzminiv.MainViewModel
//страница авторизации
@Composable
fun AuthScreen(navController: NavController, mainViewModel: MainViewModel) {
    val email = remember { mutableStateOf("") }
    val password = remember { mutableStateOf("") }

    // Слушаем результат авторизации
    val authResult by mainViewModel.authResult

    // Если авторизация прошла успешно, переходим на main_screen
    LaunchedEffect(authResult) {
        if (authResult == "Success") {
            navController.navigate("main_screen") {
                popUpTo("auth_screen") { inclusive = true }
            }
        }
    }

    Box(
        modifier = Modifier.fillMaxSize(),
        contentAlignment = Alignment.Center
    ) {
        Column(
            horizontalAlignment = Alignment.CenterHorizontally,
            verticalArrangement = Arrangement.Center,
            modifier = Modifier
                .fillMaxWidth()
                .padding(16.dp)
        ) {
            OutlinedTextField(
                value = email.value,
                onValueChange = { newText -> email.value = newText },
                label = { Text("Email") },
                modifier = Modifier.fillMaxWidth()
            )
            Spacer(modifier = Modifier.height(16.dp))
            OutlinedTextField(
                value = password.value,
                onValueChange = { newText -> password.value = newText },
                label = { Text("Password") },
                visualTransformation = PasswordVisualTransformation(),
                modifier = Modifier.fillMaxWidth()
            )
            Spacer(modifier = Modifier.height(24.dp))
            Button(onClick = {
                mainViewModel.onSignInEmailPassword(email.value, password.value)
            }) {
                Text("Login")
            }

            // Отображаем сообщение об ошибке, если авторизация не удалась
            if (authResult == "Error") {
                Spacer(modifier = Modifier.height(16.dp))
                Text(text = "Ошибка: неверный email или пароль", color = MaterialTheme.colorScheme.error)
            }
        }
    }
}
